@@ -15,7 +15,7 @@ function(req, res){
 #* @filter foo2
 function(req, res, type=""){
   if (type == "json"){
-    res$serializer <- plumber:::jsonSerializer()
+    res$serializer <- plumber:::serializer_json()
   }
   forward()
 }
